@@ -7,14 +7,22 @@ import sys
 # stop and start apache decorator
 def apache(f):
     def deco(self, *args, **kw):
-        self._stop_apache()
+        self.stop_apache()
         d = f(self, *args, **kw)
-        self._start_apache()
+        self.start_apache()
         return d
     return deco
 
 class Fabric(object):
+    """
+    Initialise an edina fabric helper.
 
+    project - project name
+    target - target directory (relative to $HOME)
+    source_path - the path to the source code (relative to source root)
+    apache_dir - full path to an apache installation (if None given assume
+                $target_dir/www)
+    """
     def __init__(self, project, target='local', source_path=None, apache_dir=None):
         self.project = project
         self.host = env.host
@@ -25,7 +33,7 @@ class Fabric(object):
         else:
             self.source_dir = self.source_root
 
-        self.virtual_env = os.sep.edina/admin.pyjoin((os.environ['HOME'], target))
+        self.virtual_env = os.sep.join((os.environ['HOME'], target))
 
         if self.host:
             # note: use echo $HOME instead of '~'
@@ -81,6 +89,12 @@ class Fabric(object):
     def release(self, app=None, skip_code_check=False, do_django_tests=False):
         """
         Release new version of a single application.
+
+        app - the application to be run
+        skip_code_check - skip code checking with pep8? If code check fails,
+                          release is postponed.
+        do_django_tests - do django unit tests? If code tests fail,
+                          release is postponed.
         """
         if not app:
             app = self.project
@@ -138,7 +152,12 @@ class Fabric(object):
         local('git tag -a v%s -m "%s"' % (version, msg))
 
     def run_tests(self, app=None, do_django=True):
-        """Run tests locally"""
+        """
+        Run tests locally
+
+        app - the application to run tests on. If None all are run.
+        do_django - do django unit tests?
+        """
         if not app:
             app = self.project
 
@@ -160,6 +179,11 @@ class Fabric(object):
                 self.source_dir, app), capture=False)
 
     def code_check(self, app=None):
+        """
+        Run pep8 code checker
+
+        app - the app to code check
+        """
         if not app:
             app = self.project
 
@@ -192,7 +216,7 @@ class Fabric(object):
                                     'etc',
                                     'requirements.txt'))
             if os.path.isfile(req_file):
-                self._virtualenv('pip install -r %s' % req_file)
+                self.virtualenv('pip install -r %s' % req_file)
             else:
                 print '*** WARN: No dependencies found at %s' % req_file
 
@@ -218,23 +242,37 @@ class Fabric(object):
                     run('mkdir etc')
                     remote_etc_dir = os.sep.join((self.target_dir, self.project, 'etc'))
                     put(req_file, remote_etc_dir)
-                    self._venvremote('pip install -r %s' %
-                                     os.sep.join((remote_etc_dir,
-                                                  'requirements.txt')))
+                    self.venvremote('pip install -r %s' %
+                                    os.sep.join((remote_etc_dir,
+                                                 'requirements.txt')))
                 else:
                     print '*** WARN: No dependencies found at %s' % req_file
 
-    def _virtualenv(self, command):
-        # run command using virtual environment
-        # and the current runtime directory
-        local('. %s/bin/activate && %s' % (self.proj_dir, command), capture=False)
+    def virtualenv(self, command, capture=False):
+        """
+        Run command using virtual environment and the current runtime directory.
 
-    def _venvremote(self, command):
-        # run command using virtual environment
-        run('. %s/bin/activate && %s' % (self.proj_dir, command))
+        command - the command to run
+        capture - capture command output?
+        """
+        return local('. %s/bin/activate && %s' % (self.proj_dir, command), capture=capture)
 
-    def _stop_apache(self):
-        run('%s/bin/apachectl stop' % self.apache_dir)
+    def venvremote(self, command):
+        """
+        Run command using virtual environment.
 
-    def _start_apache(self):
-        run('%s/bin/apachectl start' % self.apache_dir)
+        command - the command to run
+        """
+        return run('. %s/bin/activate && %s' % (self.proj_dir, command))
+
+    def stop_apache(self):
+        """
+        Stop apache.
+        """
+        return run('%s/bin/apachectl stop' % self.apache_dir)
+
+    def start_apache(self):
+        """
+        Start apache.
+        """
+        return run('%s/bin/apachectl start' % self.apache_dir)
